#include <glib.h>
#include <network_api.h>
#include <gconf/gconf-client.h>

#define CONNECTIONS_DIR "/system/osso/connectivity/IAP"

gchar * ver = ICD_NW_MODULE_VERSION;

static void
nw_start_search_fn (const gchar *network_type,
                           guint search_scope,
                           icd_nw_search_cb_fn search_cb,
                           const gpointer search_cb_token,
                           gpointer *private) {
	GConfClient* gconf;
	GSList * dirs, *d;

	gconf = gconf_client_get_default ();

	dirs = gconf_client_all_dirs(gconf, CONNECTIONS_DIR, NULL);
	if (dirs && g_slist_length (dirs)>0) {
		d = dirs;
		while(d) {
			gchar *n, *id, key[256], *t, *m;
			n=d->data;

			id = g_path_get_basename(n);
			g_snprintf(key, 255, "%s/type", n);
			t=gconf_client_get_string(gconf, key, NULL);
			if ( ! strcmp("DUMMY", t)) {
				g_snprintf(key, 255, "%s/name", n);
				m=gconf_client_get_string(gconf, key, NULL);
				if(m) search_cb(ICD_NW_SEARCH_CONTINUE, m, 
						"DUMMY", ICD_NW_ATTR_IAPNAME | ICD_NW_ATTR_AUTOCONNECT, 
						id, ICD_NW_LEVEL_10, "station_dummy0", -3, search_cb_token);
				g_free(m);
			}
			g_free(id);
			g_free(t);
			d=d->next;
		}
		g_slist_foreach (dirs, (GFunc) g_free, NULL);
		g_slist_free(dirs);
	}
	g_object_unref(gconf);
	search_cb(ICD_NW_SEARCH_COMPLETE, NULL, NULL, 0,  NULL, 0, NULL, 0, search_cb_token);
}

static void ip_up (const gchar *network_type, 
		const guint network_attrs,
		const gchar *network_id,
	       	const gchar *interface_name,
	       	icd_nw_ip_up_cb_fn ip_up_cb,
	       	gpointer ip_up_cb_token, 
		gpointer *private)
{
	  const gchar const *env_set[] = {
		      "METHOD=manual",
		          NULL
	  };

	    ip_up_cb (ICD_NW_SUCCESS_NEXT_LAYER, NULL, ip_up_cb_token, NULL, NULL);
}

static void link_post_up (const gchar *network_type,
                                const guint network_attrs,
                                const gchar *network_id,
                                const gchar *interface_name,
                                icd_nw_link_post_up_cb_fn link_post_up,
                                const gpointer link_post_up_cb_token,
                                gpointer *private)
{
  link_post_up (ICD_NW_SUCCESS_NEXT_LAYER, NULL, link_post_up_cb_token, NULL);
}


static void link_up (const gchar *network_type,
                           const guint network_attrs,
                           const gchar *network_id,
                           icd_nw_link_up_cb_fn link_up_cb,
                           const gpointer link_up_cb_token,
                           gpointer *private)
{
  link_up_cb (ICD_NW_SUCCESS_NEXT_LAYER, NULL, "dummy0", link_up_cb_token, NULL);
}


gboolean icd_nw_init (struct icd_nw_api *network_api, 
		icd_nw_watch_pid_fn watch_fn, 
		gpointer watch_fn_token, 
		icd_nw_close_fn close_fn, 
		icd_nw_status_change_fn status_change_fn, 
		icd_nw_renew_fn renew_fn) {
	
	network_api->version = ver;
	network_api->private = (void *)0x1234abcd;
	network_api->ip_down = NULL;
	network_api->ip_up = ip_up;
	network_api->ip_addr_info = NULL;
	network_api->ip_stats = NULL;
	network_api->link_pre_down = NULL;
	network_api->link_post_up = link_post_up;
	network_api->link_post_stats = NULL;
	network_api->link_down = NULL;
	network_api->link_up = link_up;
	network_api->link_stats = NULL;
	network_api->search_lifetime = 31;
	network_api->search_interval = 30;
	network_api->start_search = nw_start_search_fn;
	network_api->stop_search = NULL;
	network_api->child_exit = NULL;
	network_api->network_destruct = NULL;
	network_api->ip_renew = NULL;
	network_api->link_post_renew = NULL;
	network_api->link_renew = NULL;

	return TRUE;
}
